#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.


"""
Test helpers for shared system
"""
from contextlib import contextmanager

from workspaces.capability.schema import (
    Capability,
    CapabilityExecution,
    CapabilityRequest,
    CapabilityVersion,
    CapabilityVersionFile,
)
from workspaces.capability.services.capability_info import CapabilityInfo

SQLITE_MIN_INT = -9223372036854775808
SQLITE_MAX_INT = 9223372036854775807
SAMPLE_CAPABILITY_NAMES = ["test1", "test2", "test3"]
TEST_CAPABILITY_REQUEST_ID = 8


@contextmanager
def clear_test_database(mock_capability_info: CapabilityInfo):
    """
    Clear out test database in order to reset the test environment

    :param mock_capability_info: Test CapabilityInfo object
    """
    mock_capability_info.session.query(Capability).delete()
    mock_capability_info.session.query(CapabilityRequest).delete()
    mock_capability_info.session.query(CapabilityExecution).delete()
    mock_capability_info.session.query(CapabilityVersion).delete()
    mock_capability_info.session.query(CapabilityVersionFile).delete()
    yield
    mock_capability_info.session.query(Capability).delete()
    mock_capability_info.session.query(CapabilityRequest).delete()
    mock_capability_info.session.query(CapabilityExecution).delete()
    mock_capability_info.session.query(CapabilityVersion).delete()
    mock_capability_info.session.query(CapabilityVersionFile).delete()
